@@ -6,10 +6,14 @@ radiocc
 
 import logging
 import os
+import string
 from pathlib import Path
+from typing import Optional
 
-from radiocc import config
-from radiocc.core import run
+from pkg_resources import get_distribution
+
+from radiocc import config, download_data, interface, process_descriptor
+from radiocc.core import enable_gui, run
 
 from .model import Bands, Layers
 
@@ -17,11 +21,10 @@ __all__ = [
     "Bands",
     "Layers",
     "run",
+    "enable_gui",
 ]
 
-# Project variables.
-NAME = "radiocc"
-VERSION = "0.5.0"
+__version__ = get_distribution("radiocc").version
 
 # Logging settings.
 LOG_LEVEL = logging.DEBUG
@@ -32,8 +35,9 @@ LOG_DATEFMT = "%m/%d/%Y %I:%M:%S %p"
 SRC_PATH = Path(os.path.realpath(__file__)).parent
 ASSETS_PATH = SRC_PATH / "assets"
 CFG_PATH = Path("radiocc.yaml")
-LOG_PATH = Path(f"{NAME}.log")
+LOG_PATH = Path("radiocc.log")
 INFORMATION_PATH = ASSETS_PATH / "information"
+DESCRIPTOR_FILENAME = "descriptor.yaml"
 
 # Start logging.
 logging.basicConfig(
@@ -43,8 +47,16 @@ logging.basicConfig(
     datefmt=LOG_DATEFMT,
 )
 logging.getLogger("matplotlib").setLevel(logging.WARNING)
-LOGGER = logging.getLogger(NAME)
+LOGGER = logging.getLogger("radiocc")
 LOGGER.info("Logging enabled.")
 
 # Configurable parameters definition.
 cfg = config.Cfg()
+gui: Optional[interface.Interface] = None
+quick_trace_to_process_and_time: Optional[dict[str, str]] = None
+
+# General Constants.
+SPICE_MAVEN_DIRECTORY = Path("spice-maven/mk")
+TEMPORARY_DOWNLOAD_DIRECTORY = Path("temporary-download-location")
+MAVEN_DIRNAME_TEMPLATE = string.Template("maven $DATE")
+DATE_FMT_FOLDER = "YYYY-MMM-DD HH:mm:ss"
