@@ -153,23 +153,23 @@ class Scenario:
 class MexData:
     """Input data from MEX."""
 
-    ET: NDArray[float]
+    ET: NDArray
     UTC: List[str]
-    DISTANCE: NDArray[float]
-    DOPPLER: NDArray[float]
-    DIFF_DOPPLER: NDArray[float]
-    ERROR: NDArray[float]
+    DISTANCE: NDArray
+    DOPPLER: NDArray
+    DIFF_DOPPLER: NDArray
+    ERROR: NDArray
     FSUP: float
-    SURFACES_CONDITIONS: NDArray[bool]
-    INTEGRAL_CONDITIONS: NDArray[bool]
+    SURFACES_CONDITIONS: NDArray
+    INTEGRAL_CONDITIONS: NDArray
 
 
 class MavenData:
     """Input data from MAVEN."""
 
-    ET: NDArray[float]
+    ET: NDArray
     # FSKY: NDArray[float]
-    DOPPLER: NDArray[float]
+    DOPPLER: NDArray
 
 
 class L2Data:
@@ -191,12 +191,12 @@ class PressTemp:
     temperature.
     """
 
-    P_low: NDArray[float]
-    P_med: NDArray[float]
-    P_upp: NDArray[float]
-    T_low: NDArray[float]
-    T_med: NDArray[float]
-    T_upp: NDArray[float]
+    P_low: NDArray
+    P_med: NDArray
+    P_upp: NDArray
+    T_low: NDArray
+    T_med: NDArray
+    T_upp: NDArray
 
 
 class Export:
@@ -205,17 +205,17 @@ class Export:
     DATA_PATH: Path
     PLOT_PATH: Path
     EPHE_PATH: Path
-    ET: NDArray[float]
-    DOPPLER: NDArray[float]
-    DOPPLER_DEBIAS: NDArray[float]
-    DOPPLER_BIAS_FIT: NDArray[float]
-    DISTANCE: NDArray[float]
-    ALTITUDE: NDArray[float]
-    REFRACTIVITY: NDArray[float]
-    NE: NDArray[float]
-    TEC: Optional[NDArray[float]] = None
-    ERROR: NDArray[float]
-    ERROR_REFRAC: NDArray[float]
-    ERROR_ELEC: NDArray[float]
+    ET: NDArray
+    DOPPLER: NDArray
+    DOPPLER_DEBIAS: NDArray
+    DOPPLER_BIAS_FIT: NDArray
+    DISTANCE: NDArray
+    ALTITUDE: NDArray
+    REFRACTIVITY: NDArray
+    NE: NDArray
+    TEC: Optional[NDArray] = None
+    ERROR: NDArray
+    ERROR_REFRAC: NDArray
+    ERROR_ELEC: NDArray
     PT: Optional[PressTemp] = None
-    BEND_RADIUS: NDArray[float]
+    BEND_RADIUS: NDArray
