@@ -6,11 +6,13 @@ Created on Sun Aug 30 20:17:48 2020
 @author: ananya
 """
 
-import numpy as np
 import matplotlib.pyplot as plt
+import numpy as np
 import scipy.stats as sc
+from pudb import set_trace as bp  # noqa: F401
+
 import radiocc
-from pudb import set_trace as bp #noqa: F401
+
 
 def PLOT1( distance,Doppler,Doppler_debias,refractivity, Ne,PLOT_DIR,item):
     
@@ -44,10 +46,10 @@ def PLOT1( distance,Doppler,Doppler_debias,refractivity, Ne,PLOT_DIR,item):
     Doppler = Doppler[cond_dop]
     Doppler_debias = Doppler_debias[cond_deb]
         
-    min_x1 = np.nanmedian(Doppler_debias)- sc.median_absolute_deviation(Doppler_debias,nan_policy='omit')*5
-    min_x2 = np.nanmedian(Doppler)- sc.median_absolute_deviation(Doppler,nan_policy='omit')*5
-    max_x1 = np.nanmedian(Doppler_debias)+ sc.median_absolute_deviation(Doppler_debias,nan_policy='omit')*5
-    max_x2 = np.nanmedian(Doppler)+ sc.median_absolute_deviation(Doppler,nan_policy='omit')*5    
+    min_x1 = np.nanmedian(Doppler_debias)- sc.median_abs_deviation(Doppler_debias,nan_policy='omit')*5
+    min_x2 = np.nanmedian(Doppler)- sc.median_abs_deviation(Doppler,nan_policy='omit')*5
+    max_x1 = np.nanmedian(Doppler_debias)+ sc.median_abs_deviation(Doppler_debias,nan_policy='omit')*5
+    max_x2 = np.nanmedian(Doppler)+ sc.median_abs_deviation(Doppler,nan_policy='omit')*5    
     min_x = min([min_x1,min_x2])
     max_x = max([max_x1,max_x2])
 
