@@ -1,18 +1,18 @@
-import numpy as np
-import os
-import matplotlib.pyplot as plt
 import csv
-import pylab
-import matplotlib.ticker
-import sys
-import pandas as pd
-import sys
-import scipy.stats as sc
-import matplotlib
 import glob
+import os
+import sys
 
+import matplotlib
+import matplotlib.pyplot as plt
+import matplotlib.ticker
+import numpy as np
+import pandas as pd
+import pylab
+import scipy.stats as sc
 from pudb import set_trace as bp  # noqa: F401
 
+
 def PLOT2(
     DATA_ID,
     i_Profile,
@@ -49,6 +49,7 @@ def PLOT2(
     Doppler_debias = []
     Doppler_biasfit = []
     distance = []
+    altitude = []
     refractivity1 = []
     Ne = []
     error = []
@@ -62,12 +63,13 @@ def PLOT2(
         Doppler_debias.append(output_data_IONO[i][2])
         Doppler_biasfit.append(output_data_IONO[i][3])
         distance.append(output_data_IONO[i][4])
-        refractivity1.append(output_data_IONO[i][5])
-        Ne.append(output_data_IONO[i][6])
-        error.append(output_data_IONO[i][7])
-        error_refrac1.append(output_data_IONO[i][8])
-        error_elec.append(output_data_IONO[i][9])
-        TEC.append(output_data_IONO[i][10])
+        altitude.append(output_data_IONO[i][5])
+        refractivity1.append(output_data_IONO[i][6])
+        Ne.append(output_data_IONO[i][7])
+        error.append(output_data_IONO[i][8])
+        error_refrac1.append(output_data_IONO[i][9])
+        error_elec.append(output_data_IONO[i][10])
+        TEC.append(output_data_IONO[i][11])
 
     Python_OUT_ATMO = []
     N_data_ATMO = []
@@ -85,6 +87,7 @@ def PLOT2(
     Doppler_debias = []
     Doppler_biasfit = []
     distance = []
+    altitude = []
     refractivity2 = []
     Nn = []
     error = []
@@ -103,17 +106,18 @@ def PLOT2(
         Doppler_debias.append(output_data_ATMO[i][2])
         Doppler_biasfit.append(output_data_ATMO[i][3])
         distance.append(output_data_ATMO[i][4])
-        refractivity2.append(output_data_ATMO[i][5])
-        Nn.append(output_data_ATMO[i][6])
-        error.append(output_data_ATMO[i][7])
-        error_refrac2.append(output_data_ATMO[i][8])
-        error_neut.append(output_data_ATMO[i][9])
-        P_low.append(output_data_ATMO[i][10])
-        P_med.append(output_data_ATMO[i][11])
-        P_upp.append(output_data_ATMO[i][12])
-        T_low.append(output_data_ATMO[i][13])
-        T_med.append(output_data_ATMO[i][14])
-        T_upp.append(output_data_ATMO[i][15])
+        altitude.append(output_data_IONO[i][5])
+        refractivity2.append(output_data_ATMO[i][6])
+        Nn.append(output_data_ATMO[i][7])
+        error.append(output_data_ATMO[i][8])
+        error_refrac2.append(output_data_ATMO[i][9])
+        error_neut.append(output_data_ATMO[i][10])
+        P_low.append(output_data_ATMO[i][11])
+        P_med.append(output_data_ATMO[i][12])
+        P_upp.append(output_data_ATMO[i][13])
+        T_low.append(output_data_ATMO[i][14])
+        T_med.append(output_data_ATMO[i][15])
+        T_upp.append(output_data_ATMO[i][16])
 
     # #########print L2_data#################################################################################
     # os.chdir(DATA_PRO)
@@ -186,19 +190,19 @@ def PLOT2(
 
     min_x1 = (
         np.nanmedian(Doppler_debias1)
-        - sc.median_absolute_deviation(Doppler_debias1, nan_policy="omit") * 5
+        - sc.median_abs_deviation(Doppler_debias1, nan_policy="omit") * 5
     )
     min_x2 = (
         np.nanmedian(Doppler1)
-        - sc.median_absolute_deviation(Doppler1, nan_policy="omit") * 5
+        - sc.median_abs_deviation(Doppler1, nan_policy="omit") * 5
     )
     max_x1 = (
         np.nanmedian(Doppler_debias1)
-        + sc.median_absolute_deviation(Doppler_debias1, nan_policy="omit") * 5
+        + sc.median_abs_deviation(Doppler_debias1, nan_policy="omit") * 5
     )
     max_x2 = (
         np.nanmedian(Doppler1)
-        + sc.median_absolute_deviation(Doppler1, nan_policy="omit") * 5
+        + sc.median_abs_deviation(Doppler1, nan_policy="omit") * 5
     )
     min_x = min([min_x1, min_x2])
     max_x = max([max_x1, max_x2])
@@ -298,7 +302,7 @@ def PLOT2(
     min_x = np.nanmin(np.array(refractivity2)[cond_ref2])
     max_x = (
         np.nanmedian(np.array(refractivity2)[cond_ref2])
-        + sc.median_absolute_deviation(
+        + sc.median_abs_deviation(
             np.array(refractivity2)[cond_ref2], nan_policy="omit"
         )
         * 3
@@ -371,7 +375,7 @@ def PLOT2(
     min_x = np.nanmin(np.array(refractivity1)[cond_ref1])
     max_x = (
         np.nanmedian(np.array(refractivity1)[cond_ref1])
-        + sc.median_absolute_deviation(
+        + sc.median_abs_deviation(
             np.array(refractivity1)[cond_ref1], nan_policy="omit"
         )
         * 3
@@ -450,10 +454,10 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(Ne) - sc.median_absolute_deviation(Ne, nan_policy="omit") * 3
+    min_x = np.nanmedian(Ne) - sc.median_abs_deviation(Ne, nan_policy="omit") * 3
     max_x = (
         np.nanmax(np.array(Ne)[np.array(Ne) < 1e13])
-        + sc.median_absolute_deviation(
+        + sc.median_abs_deviation(
             np.array(Ne)[np.array(Ne) < 1e13], nan_policy="omit"
         )
         * 3
@@ -598,8 +602,8 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(Nn) - sc.median_absolute_deviation(Nn, nan_policy="omit") * 3
-    max_x = np.nanmedian(Nn) + sc.median_absolute_deviation(Nn, nan_policy="omit") * 9
+    min_x = np.nanmedian(Nn) - sc.median_abs_deviation(Nn, nan_policy="omit") * 3
+    max_x = np.nanmedian(Nn) + sc.median_abs_deviation(Nn, nan_policy="omit") * 9
 
     plt.grid(True)
     plt.xlim(xmin=-1e22, xmax=3e23)
@@ -649,8 +653,8 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(T_low) - sc.median_absolute_deviation(T_low, nan_policy="omit") * 3
-    max_x = np.nanmedian(T_low) + sc.median_absolute_deviation(T_low, nan_policy="omit") * 9
+    min_x = np.nanmedian(T_low) - sc.median_abs_deviation(T_low, nan_policy="omit") * 3
+    max_x = np.nanmedian(T_low) + sc.median_abs_deviation(T_low, nan_policy="omit") * 9
 
     plt.grid(True)
     plt.xlim(min_x, max_x)
@@ -700,8 +704,8 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(T_med) - sc.median_absolute_deviation(T_med, nan_policy="omit") * 3
-    max_x = np.nanmedian(T_med) + sc.median_absolute_deviation(T_med, nan_policy="omit") * 9
+    min_x = np.nanmedian(T_med) - sc.median_abs_deviation(T_med, nan_policy="omit") * 3
+    max_x = np.nanmedian(T_med) + sc.median_abs_deviation(T_med, nan_policy="omit") * 9
 
     plt.grid(True)
     plt.xlim(min_x, max_x)
@@ -751,8 +755,8 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(T_upp) - sc.median_absolute_deviation(T_upp, nan_policy="omit") * 3
-    max_x = np.nanmedian(T_upp) + sc.median_absolute_deviation(T_upp, nan_policy="omit") * 9
+    min_x = np.nanmedian(T_upp) - sc.median_abs_deviation(T_upp, nan_policy="omit") * 3
+    max_x = np.nanmedian(T_upp) + sc.median_abs_deviation(T_upp, nan_policy="omit") * 9
 
     plt.grid(True)
     plt.xlim(min_x, max_x)
@@ -802,8 +806,8 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(P_low) - sc.median_absolute_deviation(P_low, nan_policy="omit") * 3
-    max_x = np.nanmedian(P_low) + sc.median_absolute_deviation(P_low, nan_policy="omit") * 9
+    min_x = np.nanmedian(P_low) - sc.median_abs_deviation(P_low, nan_policy="omit") * 3
+    max_x = np.nanmedian(P_low) + sc.median_abs_deviation(P_low, nan_policy="omit") * 9
 
     plt.grid(True)
     plt.xlim(min_x, max_x)
@@ -853,8 +857,8 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(P_med) - sc.median_absolute_deviation(P_med, nan_policy="omit") * 3
-    max_x = np.nanmedian(P_med) + sc.median_absolute_deviation(P_med, nan_policy="omit") * 9
+    min_x = np.nanmedian(P_med) - sc.median_abs_deviation(P_med, nan_policy="omit") * 3
+    max_x = np.nanmedian(P_med) + sc.median_abs_deviation(P_med, nan_policy="omit") * 9
 
     plt.grid(True)
     plt.xlim(min_x, max_x)
@@ -904,8 +908,8 @@ def PLOT2(
     plt.xticks(fontsize=13)
     plt.yticks(fontsize=13)
 
-    min_x = np.nanmedian(P_upp) - sc.median_absolute_deviation(P_upp, nan_policy="omit") * 3
-    max_x = np.nanmedian(P_upp) + sc.median_absolute_deviation(P_upp, nan_policy="omit") * 9
+    min_x = np.nanmedian(P_upp) - sc.median_abs_deviation(P_upp, nan_policy="omit") * 3
+    max_x = np.nanmedian(P_upp) + sc.median_abs_deviation(P_upp, nan_policy="omit") * 9
 
     plt.grid(True)
     plt.xlim(min_x, max_x)
