@@ -68,7 +68,7 @@ def run(
     T_BC_low,
     T_BC_med,
     T_BC_upp,
-    DATA_TYPE: Optional[radiocc.model.RadioDataType]
+    DATA_TYPE: Optional[radiocc.model.RadioDataType],
 ):
     kx = 880.0 / 749.0
     ks = 240.0 / 749.0
