@@ -6,11 +6,12 @@ Created on Sun Aug 30 19:52:33 2020
 @author: ananya
 """
 
+from typing import Optional
+
 import matplotlib.pyplot as plt
 import numpy as np
 import scipy.stats as sc
 from pudb import set_trace as bp  # noqa
-from typing import Optional
 
 import radiocc
 
@@ -60,19 +61,19 @@ def PLOT_Dop1(distance, Doppler, Doppler_debias, Doppler_biasfit, ET, PLOT_DIR,
 
     min_x1 = (
         np.nanmedian(Doppler_debias)
-        - sc.median_absolute_deviation(Doppler_debias, nan_policy="omit") * 5
+        - sc.median_abs_deviation(Doppler_debias, nan_policy="omit") * 5
     )
     min_x2 = (
         np.nanmedian(Doppler)
-        - sc.median_absolute_deviation(Doppler, nan_policy="omit") * 5
+        - sc.median_abs_deviation(Doppler, nan_policy="omit") * 5
     )
     max_x1 = (
         np.nanmedian(Doppler_debias)
-        + sc.median_absolute_deviation(Doppler_debias, nan_policy="omit") * 5
+        + sc.median_abs_deviation(Doppler_debias, nan_policy="omit") * 5
     )
     max_x2 = (
         np.nanmedian(Doppler)
-        + sc.median_absolute_deviation(Doppler, nan_policy="omit") * 5
+        + sc.median_abs_deviation(Doppler, nan_policy="omit") * 5
     )
 
     if np.isnan(min_x1) and np.isnan(max_x1):
@@ -106,19 +107,19 @@ def PLOT_Dop1(distance, Doppler, Doppler_debias, Doppler_biasfit, ET, PLOT_DIR,
     
     min_x1 = (
         np.nanmedian(Doppler_debias)
-        - sc.median_absolute_deviation(Doppler_debias, nan_policy="omit") * 5
+        - sc.median_abs_deviation(Doppler_debias, nan_policy="omit") * 5
     )
     min_x2 = (
         np.nanmedian(Doppler)
-        - sc.median_absolute_deviation(Doppler, nan_policy="omit") * 5
+        - sc.median_abs_deviation(Doppler, nan_policy="omit") * 5
     )
     max_x1 = (
         np.nanmedian(Doppler_debias)
-        + sc.median_absolute_deviation(Doppler_debias, nan_policy="omit") * 5
+        + sc.median_abs_deviation(Doppler_debias, nan_policy="omit") * 5
     )
     max_x2 = (
         np.nanmedian(Doppler)
-        + sc.median_absolute_deviation(Doppler, nan_policy="omit") * 5
+        + sc.median_abs_deviation(Doppler, nan_policy="omit") * 5
     )
 
     if np.isnan(min_x1) and np.isnan(max_x1):
