@@ -180,7 +180,16 @@ def run(  # noqa: C901
     )
 
     # R6: footprint
-    d_lat, d_lon, dist_Mars_Sun, spclon_SC, spclat_SC, re, f = R5_Foot_Print.long_lat(
+    (
+        d_radius,
+        d_lat,
+        d_lon,
+        dist_Mars_Sun,
+        spclon_SC,
+        spclat_SC,
+        re,
+        f,
+    ) = R5_Foot_Print.long_lat(
         N_data, pos_MEX, vel_MEX, ET, ET_MEX_Mars, Ref_frame, l2_data.FOLDER_TYPE
     )
 
@@ -714,6 +723,8 @@ def run(  # noqa: C901
         N_data, fsup, error, c, distance, Threshold_neut_upp, V, e, eps0, me, Bande, CC
     )
 
+    ALTITUDE = bend_radius - d_radius * 1e3
+
     # Return variables to be exported.
 
     export.DATA_PATH = Path(DATA_FINAL_DIR)
@@ -724,6 +735,7 @@ def run(  # noqa: C901
     export.DOPPLER_DEBIAS = Doppler_debias
     export.DOPPLER_BIAS_FIT = Doppler_biasfit
     export.DISTANCE = distance
+    export.ALTITUDE = ALTITUDE
     export.REFRACTIVITY = refractivity
     export.ERROR = error
     export.ERROR_REFRAC = error_ref
